cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;
return plural;
},
  "language": "ru",
  "x-generator": "Weblate 4.0.4"
 },
 "$0 documentation": [
  null,
  "Документация $0"
 ],
 "$0 exited with code $1": [
  null,
  "Процесс $0 завершил работу с кодом $1"
 ],
 "$0 failed": [
  null,
  "Сбой процесса $0"
 ],
 "$0 killed with signal $1": [
  null,
  "Процесс $0 прерван с сигналом $1"
 ],
 "A compatible version of Cockpit is not installed on {{#strong}}{{host}}{{/strong}}.": [
  null,
  "Совместимая версия Cockpit не установлена ​​на {{#strong}}{{host}}{{/strong}}."
 ],
 "A new SSH key at ${key} will be created for ${luser} on ${lhost} and it will be added to the ${afile} file of ${ruser} on ${rhost}.": [
  null,
  ""
 ],
 "About Web Console": [
  null,
  "О веб-консоли"
 ],
 "Accept key and connect": [
  null,
  ""
 ],
 "Active pages": [
  null,
  "Активные страницы"
 ],
 "Add": [
  null,
  "Добавить"
 ],
 "Apps": [
  null,
  ""
 ],
 "Authentication": [
  null,
  "Проверка подлинности"
 ],
 "By changing the password of the SSH key ${key} to the login password of ${luser} on ${lhost}, the key will be automatically made available and you can log in to ${rhost} without password in the future.": [
  null,
  ""
 ],
 "Can be a hostname, IP address, alias name, or ssh:// URI": [
  null,
  ""
 ],
 "Cancel": [
  null,
  "Отмена"
 ],
 "Cannot forward login credentials": [
  null,
  "Не удаётся передать учётные данные для входа"
 ],
 "Change password": [
  null,
  "Изменить пароль"
 ],
 "Clear search": [
  null,
  "Сбросить поиск"
 ],
 "Close": [
  null,
  "Закрыть"
 ],
 "Close selected pages": [
  null,
  "Закрыть выделенные страницы"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Не удалось установить связь между Cockpit и заданным узлом."
 ],
 "Cockpit had an unexpected internal error.": [
  null,
  ""
 ],
 "Cockpit is an interactive Linux server admin interface.": [
  null,
  "Cockpit — это интерактивный интерфейс администратора серверов Linux."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit не совместим с программным обеспечением в системе."
 ],
 "Cockpit is not installed": [
  null,
  "Cockpit не установлен"
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit не установлен в системе."
 ],
 "Color": [
  null,
  "Цвет"
 ],
 "Comment": [
  null,
  "Комментарий"
 ],
 "Confirm": [
  null,
  "Подтверждение"
 ],
 "Connecting simultaneously to more than {{ limit }} machines is unsupported.": [
  null,
  "Одновременное подключение к количеству компьютеров, превышающему {{ limit }}, не поддерживается."
 ],
 "Connecting to the machine": [
  null,
  "Подключение к компьютеру"
 ],
 "Connection error": [
  null,
  "Ошибка подключения"
 ],
 "Connection failed": [
  null,
  "Ошибка подключения"
 ],
 "Connection has timed out.": [
  null,
  "Превышено время ожидания подключения."
 ],
 "Continue session": [
  null,
  "Продолжить сессию"
 ],
 "Could not contact {{host}}": [
  null,
  "Не удалось связаться с {{host}}"
 ],
 "Create": [
  null,
  "Создать"
 ],
 "Create a new SSH key and authorize it.": [
  null,
  ""
 ],
 "Ctrl-Shift-J": [
  null,
  ""
 ],
 "Details": [
  null,
  "Подробности"
 ],
 "Disconnected": [
  null,
  "Отключено"
 ],
 "Display language": [
  null,
  "Язык интерфейса"
 ],
 "Edit": [
  null,
  "Изменить"
 ],
 "Edit hosts": [
  null,
  ""
 ],
 "Failed to add machine: $0": [
  null,
  "Не удалось добавить компьютер: $0"
 ],
 "Failed to change password": [
  null,
  "Не удалось изменить пароль"
 ],
 "Failed to edit machine: $0": [
  null,
  "Не удалось изменить компьютер: $0"
 ],
 "Fingerprint": [
  null,
  "Отпечаток"
 ],
 "GNU LGPL version 2.1": [
  null,
  ""
 ],
 "Help": [
  null,
  "Помощь"
 ],
 "Host": [
  null,
  "Узел"
 ],
 "Host key is incorrect": [
  null,
  "Неверный ключ узла"
 ],
 "If the fingerprint matches, click \"Accept key and connect\". Otherwise, do not connect and contact your administrator.": [
  null,
  ""
 ],
 "In order to allow log in to ${rhost} as ${ruser} without password in the future, use the login password of ${luser} on ${lhost} as the key password, or leave the key password blank.": [
  null,
  ""
 ],
 "Internal error": [
  null,
  "Внутренняя ошибка"
 ],
 "Invalid file permissions": [
  null,
  "Недопустимые разрешения для файлов"
 ],
 "Is sshd running on a different port?": [
  null,
  "Работает ли sshd на другом порту?"
 ],
 "Kerberos based SSO": [
  null,
  "SSO на основе Kerberos"
 ],
 "Learn more": [
  null,
  "Подробнее..."
 ],
 "Licensed under:": [
  null,
  "Лицензия:"
 ],
 "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
  null,
  ""
 ],
 "Log in": [
  null,
  "Войти"
 ],
 "Log in to {{host}}": [
  null,
  "Выполнить вход в {{host}}"
 ],
 "Log out": [
  null,
  "Выход"
 ],
 "Login failed": [
  null,
  "Ошибка входа"
 ],
 "Messages related to the failure might be found in the journal:": [
  null,
  "Сообщения, связанные с ошибкой, могут быть найдены в журнале:"
 ],
 "Method": [
  null,
  ""
 ],
 "New password": [
  null,
  "Новый пароль"
 ],
 "New password was not accepted": [
  null,
  "Новый пароль не был принят"
 ],
 "No results found": [
  null,
  "Нет результатов"
 ],
 "No such file or directory": [
  null,
  "Нет такого файла или каталога"
 ],
 "Not a valid private key": [
  null,
  "Недопустимый закрытый ключ"
 ],
 "Not permitted to perform this action.": [
  null,
  "Нет прав на выполнение этого действия."
 ],
 "Ok": [
  null,
  "OK"
 ],
 "Old password": [
  null,
  "Старый пароль"
 ],
 "Old password not accepted": [
  null,
  "Старый пароль не был принят"
 ],
 "Ooops!": [
  null,
  "Упс!"
 ],
 "Password": [
  null,
  "Пароль"
 ],
 "Password not accepted": [
  null,
  "Пароль не принят"
 ],
 "Path to file": [
  null,
  "Путь к файлу"
 ],
 "Please authenticate to gain administrative access": [
  null,
  ""
 ],
 "Port": [
  null,
  "Порт"
 ],
 "Project website": [
  null,
  "Веб-сайт проекта"
 ],
 "Prompting via ssh-add timed out": [
  null,
  "Превышено время ожидания запроса по ssh-add"
 ],
 "Prompting via ssh-keygen timed out": [
  null,
  "Превышено время ожидания запроса по ssh-keygen"
 ],
 "Public key": [
  null,
  "Открытый ключ"
 ],
 "Reconnect": [
  null,
  "Повторить подключение"
 ],
 "Safari users need to import and trust the certificate of the self-signing CA:": [
  null,
  "Пользователям Safari необходимо импортировать и установить доверие к самозаверенному сертификату центра сертификации:"
 ],
 "Search": [
  null,
  "Поиск"
 ],
 "Select": [
  null,
  "Выбрать"
 ],
 "Server has closed the connection.": [
  null,
  "Сервер закрыл соединение."
 ],
 "Session is about to expire": [
  null,
  "Сессия истекает"
 ],
 "Set": [
  null,
  "Настроить"
 ],
 "Something went wrong": [
  null,
  ""
 ],
 "Stop editing hosts": [
  null,
  ""
 ],
 "Switch to limited access": [
  null,
  ""
 ],
 "System": [
  null,
  "Система"
 ],
 "The SSH key ${key} of ${luser} on ${lhost} will be added to the ${afile} file of ${ruser} on ${rhost}.": [
  null,
  ""
 ],
 "The SSH key for logging in to {{#strong}}{{full_address}}{{/strong}} is protected. You can log in with either your login password or by providing the password of the key at {{#strong}}{{key}}{{/strong}}.": [
  null,
  ""
 ],
 "The SSH key {{#strong}}{{key}}{{/strong}} will be made available for the remainder of the session and will be available for login to other hosts as well.": [
  null,
  ""
 ],
 "The passwords do not match.": [
  null,
  "Пароли не совпадают."
 ],
 "The resulting fingerprint is fine to share via public methods, including email.": [
  null,
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Сервер отклонил проверку подлинности с использованием любых поддерживаемых методов."
 ],
 "There are currently no active pages": [
  null,
  "В настоящее время нет активных страниц"
 ],
 "There was an unexpected error while connecting to the machine.": [
  null,
  "Произошла непредвиденная ошибка при подключении к компьютеру."
 ],
 "This didn't work, please try again": [
  null,
  ""
 ],
 "This machine has already been added.": [
  null,
  "Этот компьютер уже добавлен."
 ],
 "This will allow you to log in without password in the future.": [
  null,
  ""
 ],
 "Tip: Make your key password match your login password to automatically authenticate against other systems.": [
  null,
  "Совет: сделайте пароль ключа и пароль для входа в систему одинаковыми для автоматической проверки подлинности в других системах."
 ],
 "To ensure that your connection is not intercepted by a malicious third-party, please verify the host key fingerprint:": [
  null,
  ""
 ],
 "To verify a fingerprint, run the following on {{host}} while physically sitting at the machine or through a trusted network:": [
  null,
  ""
 ],
 "Too much data": [
  null,
  "Слишком много данных"
 ],
 "Tools": [
  null,
  ""
 ],
 "Type": [
  null,
  "Тип"
 ],
 "Unable to log in to {{#strong}}{{full_address}}{{/strong}} using SSH key authentication. Please provide the password. You may want to set up your SSH keys for automatic login.": [
  null,
  ""
 ],
 "Unable to log in to {{#strong}}{{full_address}}{{/strong}}. The host does not accept password login or any of your SSH keys.": [
  null,
  ""
 ],
 "Unexpected error": [
  null,
  "Непредвиденная ошибка"
 ],
 "Unlock key": [
  null,
  "Разблокировать ключ"
 ],
 "Untrusted host": [
  null,
  "Недоверенный узел"
 ],
 "Update": [
  null,
  "Обновить"
 ],
 "Use the following keys to authenticate against other systems": [
  null,
  "Используйте следующие ключи для проверки подлинности в других системах"
 ],
 "User name": [
  null,
  "Имя пользователя"
 ],
 "Version": [
  null,
  "Версия"
 ],
 "Web Console": [
  null,
  "Веб-консоль"
 ],
 "When empty, connect with the current user": [
  null,
  ""
 ],
 "You are connecting to {{host}} for the first time.": [
  null,
  ""
 ],
 "You can not gain administrative access.": [
  null,
  ""
 ],
 "You have been logged out due to inactivity.": [
  null,
  "Вы вышли из системы из-за неактивности."
 ],
 "You may want to change the password of the key for automatic login.": [
  null,
  ""
 ],
 "You will be logged out in $0 seconds.": [
  null,
  "Вы выйдете из системы через $0 секунд."
 ],
 "Your browser will remember your access level across sessions.": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "Сеанс завершён."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Срок действия сеанса истёк. Войдите в систему снова."
 ],
 "active": [
  null,
  "активно"
 ],
 "in most browsers": [
  null,
  ""
 ],
 "show less": [
  null,
  "показать меньше"
 ],
 "show more": [
  null,
  "показать больше"
 ]
});
