/* Rely on the margin from the Card for spacing */
.ct-card.pf-c-card .table {
    margin-bottom: 0;
}

.ct-card.pf-c-card .pf-c-card__body.contains-list {
    padding-left: 0;
    padding-right: 0;
    padding-bottom: 0;
}

.ct-card.pf-c-card .pf-c-card__body.contains-list > .pf-c-table > :last-child > tr:last-child {
    border-bottom: none;
}

.ct-card.pf-c-card .pf-c-card__header > .pf-c-card__title {
  padding: 0;
}

.ct-card.pf-c-card .pf-c-card__title {
  font-weight: normal;
}

.ct-card.pf-c-card .pf-c-card__title > h2 {
  font-size: var(--pf-global--FontSize--2xl);
}

.ct-card.pf-c-card .pf-c-card__header {
  padding: var(--pf-global--spacer--md);
}

.ct-cards-grid {
    --ct-grid-columns: 2;
    --pf-l-gallery--GridTemplateColumns: repeat(var(--ct-grid-columns), 1fr);

    > .pf-c-card:not(.ct-card-info) {
        // Extend all non-info cards to be full width;
        // let ct-card-info fit 1 column of the grid
        grid-column: 1 / -1;
    }

    @media screen and (max-width: $pf-global--breakpoint--lg) {
        // Shrink to 1 column when space is constrained
        --ct-grid-columns: 1;
    }
}
