cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "fi",
  "x-generator": "Weblate 4.4.2"
 },
 "$0 documentation": [
  null,
  "$0 dokumentointi"
 ],
 "$0 exited with code $1": [
  null,
  "$0 poistui koodilla $1"
 ],
 "$0 failed": [
  null,
  "$0 epäonnistui"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 tapettu signaalilla $1"
 ],
 "A compatible version of Cockpit is not installed on {{#strong}}{{host}}{{/strong}}.": [
  null,
  "Yhteensopivaa versiota Cockpitistä ei ole asennettu kohteessa {{#strong}}{{host}}{{/strong}}."
 ],
 "A new SSH key at ${key} will be created for ${luser} on ${lhost} and it will be added to the ${afile} file of ${ruser} on ${rhost}.": [
  null,
  "Uusi SSH-avain ${key}:hen luodaan ${luser}:lle ${lhost}:lla ja se lisätään ${ruser}:n tiedostoon ${afile} ${rhost}:lla."
 ],
 "About Web Console": [
  null,
  "Tietoja Web Consolesta"
 ],
 "Accept key and connect": [
  null,
  "Hyväksy avain ja muodosta yhteys"
 ],
 "Active pages": [
  null,
  "Aktiiviset sivut"
 ],
 "Add": [
  null,
  "Lisää"
 ],
 "Add key": [
  null,
  "Lisää avain"
 ],
 "Add new host": [
  null,
  "Lisää uusi isäntä"
 ],
 "Administrative access": [
  null,
  "Hallinnollinen käyttöoikeus"
 ],
 "Apps": [
  null,
  "Sovellukset"
 ],
 "Authenticate": [
  null,
  "Tunnistaudu"
 ],
 "Authentication": [
  null,
  "Tunnistautuminen"
 ],
 "Authentication failed": [
  null,
  "Tunnistautuminen epäonnistui"
 ],
 "Authorize SSH key.": [
  null,
  "Valtuuta SSH-avain."
 ],
 "Automatic login": [
  null,
  "Automaattinen sisäänkirjautuminen"
 ],
 "By changing the password of the SSH key ${key} to the login password of ${luser} on ${lhost}, the key will be automatically made available and you can log in to ${rhost} without password in the future.": [
  null,
  "Vaihtamalla SSH-avaimen ${key} salasanan ${luser}:n kirjautumissalasanaksi ${lhost}:ssa, avain tulee automaattisesti saataville ja voit kirjautua sisään ${rhost} -palveluun ilman salasanaa tulevaisuudessa."
 ],
 "Can be a hostname, IP address, alias name, or ssh:// URI": [
  null,
  "Voi olla isäntänimi, IP-osoite, aliaksen nimi tai ssh:// URI"
 ],
 "Cancel": [
  null,
  "Peru"
 ],
 "Cannot connect to an unknown host": [
  null,
  "Ei voida yhdistää tuntemattomaan isäntään"
 ],
 "Cannot forward login credentials": [
  null,
  "Kirjautumistietoja ei voi välittää eteenpäin"
 ],
 "Change password": [
  null,
  "Vaihda salasana"
 ],
 "Change the password of ${key}.": [
  null,
  "Vaihda ${key}:n salasana."
 ],
 "Clear search": [
  null,
  "Tyhjennä haku"
 ],
 "Close": [
  null,
  "Sulje"
 ],
 "Close selected pages": [
  null,
  "Sulje valitut sivut"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit ei saanut yhteyttä isäntään."
 ],
 "Cockpit had an unexpected internal error.": [
  null,
  "Cockpitissa oli odottamaton sisäinen virhe."
 ],
 "Cockpit is an interactive Linux server admin interface.": [
  null,
  "Cockpit on vuorovaikutteinen Linux-palvelimen ylläpitäjän käyttöliittymä."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit ei ole yhteensopiva järjestelmän ohjelmiston kanssa."
 ],
 "Cockpit is not installed": [
  null,
  "Cockpit ei ole asennettu"
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit ei ole asennettu järjestelmässä."
 ],
 "Color": [
  null,
  "Väri"
 ],
 "Comment": [
  null,
  "Kommentti"
 ],
 "Confirm": [
  null,
  "Vahvista"
 ],
 "Confirm key password": [
  null,
  "Vahvista avaimen salasana"
 ],
 "Confirm new key password": [
  null,
  "Vahvista uusi avaimen salasana"
 ],
 "Connecting simultaneously to more than {{ limit }} machines is unsupported.": [
  null,
  "Samanaikainen yhdistäminen useampaan kuin {{ limit }} koneeseen ei ole tuettu."
 ],
 "Connecting to the machine": [
  null,
  "Yhdistetään koneeseen"
 ],
 "Connection error": [
  null,
  "Yhteysvirhe"
 ],
 "Connection failed": [
  null,
  "Yhteys epäonnistui"
 ],
 "Connection has timed out.": [
  null,
  "Yhteys aikakatkaistiin."
 ],
 "Contains:": [
  null,
  "Sisältää:"
 ],
 "Continue session": [
  null,
  "Jatka istuntoa"
 ],
 "Could not contact {{host}}": [
  null,
  "Ei saatu yhteyttä {{host}}:een"
 ],
 "Create": [
  null,
  "Luo"
 ],
 "Create a new SSH key and authorize it.": [
  null,
  "Luo uusi SSH-avain ja valtuuta se."
 ],
 "Ctrl-Shift-J": [
  null,
  "Ctrl-Vaihto-J"
 ],
 "Details": [
  null,
  "Yksityiskohdat"
 ],
 "Disconnected": [
  null,
  "Katkaistu"
 ],
 "Display language": [
  null,
  "Näytä kieli"
 ],
 "Edit": [
  null,
  "Muokkaa"
 ],
 "Edit host": [
  null,
  "Muokkaa isäntää"
 ],
 "Edit hosts": [
  null,
  "Muokkaa isäntää"
 ],
 "Error message": [
  null,
  "Virheviesti"
 ],
 "Failed to add machine: $0": [
  null,
  "Ei voitu lisätä konetta: $0"
 ],
 "Failed to change password": [
  null,
  "Salasanan vaihtaminen epäonnistui"
 ],
 "Failed to edit machine: $0": [
  null,
  "Koneen muokkaaminen epäonnistui: $0"
 ],
 "Fingerprint": [
  null,
  "Sormenjälki"
 ],
 "GNU LGPL version 2.1": [
  null,
  "GNU LGPL -versio 2.1"
 ],
 "Help": [
  null,
  "Ohjeita"
 ],
 "Host": [
  null,
  "Kone"
 ],
 "Host key is incorrect": [
  null,
  "Koneen avain on väärin"
 ],
 "Hosts": [
  null,
  "Isännät"
 ],
 "If the fingerprint matches, click \"Accept key and connect\". Otherwise, do not connect and contact your administrator.": [
  null,
  "Jos sormenjälki on sama, napsauta \"Hyväksy avain ja muodosta yhteys\". Muussa tapauksessa älä muodosta yhteyttä ja ota yhteyttä järjestelmänvalvojaan."
 ],
 "In order to allow log in to ${rhost} as ${ruser} without password in the future, use the login password of ${luser} on ${lhost} as the key password, or leave the key password blank.": [
  null,
  "Jos haluat sallia sisäänkirjautumisen ${rhost}:een käyttäjänä ${ruser} ilman salasanaa tulevaisuudessa, käytä ${luser}:n sisäänkirjautumissalasanaa ${lhost}:lla avainsalasanana tai jätä avaimen salasana tyhjä."
 ],
 "Internal error": [
  null,
  "Sisäinen virhe"
 ],
 "Invalid file permissions": [
  null,
  "Virheelliset tiedosto-oikeudet"
 ],
 "Is sshd running on a different port?": [
  null,
  "Onko sshd käynnissä eri portissa?"
 ],
 "Kerberos based SSO": [
  null,
  "Kerberos-pohjainen SSO"
 ],
 "Key password": [
  null,
  "Avaimen salasana"
 ],
 "Learn more": [
  null,
  "Opi lisää"
 ],
 "Licensed under:": [
  null,
  "Lisensoitu:"
 ],
 "Limit access": [
  null,
  "Rajoita pääsyä"
 ],
 "Limited access": [
  null,
  "Rajoitettu pääsy"
 ],
 "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
  null,
  "Rajoitettu pääsy -tila rajoittaa hallinnollisia oikeuksia. Joidenkin verkkokonsolin osien toiminnot ovat vähentyneet."
 ],
 "Log in": [
  null,
  "Kirjaudu sisään"
 ],
 "Log in to {{host}}": [
  null,
  "Kirjaudu kohteeseen {{host}}"
 ],
 "Log out": [
  null,
  "Kirjaudu ulos"
 ],
 "Login failed": [
  null,
  "Kirjautuminen epäonnistui"
 ],
 "Messages related to the failure might be found in the journal:": [
  null,
  "Virheeseen liittyvät viestit saattavat löytyä päiväkirjasta:"
 ],
 "Method": [
  null,
  "Menetelmä"
 ],
 "New host": [
  null,
  "Uusi isäntä"
 ],
 "New key password": [
  null,
  "Uuden avaimen salasana"
 ],
 "New password": [
  null,
  "Uusi salasana"
 ],
 "New password was not accepted": [
  null,
  "Uutta salasanaa ei hyväksytty"
 ],
 "No results found": [
  null,
  "Tuloksia ei löytynyt"
 ],
 "No such file or directory": [
  null,
  "Ei tällaista tiedostoa tai hakemistoa"
 ],
 "Not a valid private key": [
  null,
  "Ei kelvollinen yksityinen avain"
 ],
 "Not connected to host": [
  null,
  "Ei yhdistetty isäntään"
 ],
 "Not permitted to perform this action.": [
  null,
  "Ei oikeutta suorittaa tätä toimintoa."
 ],
 "Ok": [
  null,
  "OK"
 ],
 "Old password": [
  null,
  "Vanha salasana"
 ],
 "Old password not accepted": [
  null,
  "Vanhaa salasanaa ei hyväksytty"
 ],
 "Ooops!": [
  null,
  "Hups!"
 ],
 "Page name": [
  null,
  "Sivun nimi"
 ],
 "Password": [
  null,
  "Salasana"
 ],
 "Password not accepted": [
  null,
  "Salasanaa ei hyväksytty"
 ],
 "Path to file": [
  null,
  "Polku tiedostoon"
 ],
 "Please authenticate to gain administrative access": [
  null,
  "Todenna saadaksesi hallinnolliset käyttöoikeudet"
 ],
 "Port": [
  null,
  "Portti"
 ],
 "Project website": [
  null,
  "Projektin verkkosivusto"
 ],
 "Prompting via ssh-add timed out": [
  null,
  "Kysely 'ssh-add':in kautta aikakatkaistiin"
 ],
 "Prompting via ssh-keygen timed out": [
  null,
  "Kysely 'ssh-keygen':in kautta aikakatkaistiin"
 ],
 "Public key": [
  null,
  "Julkinen avain"
 ],
 "Reconnect": [
  null,
  "Yhdistä uudelleen"
 ],
 "SSH key": [
  null,
  "SSH-avain"
 ],
 "SSH keys": [
  null,
  "SSH-avaimet"
 ],
 "Safari users need to import and trust the certificate of the self-signing CA:": [
  null,
  ""
 ],
 "Search": [
  null,
  "Haku"
 ],
 "Select": [
  null,
  "Valitse"
 ],
 "Server has closed the connection.": [
  null,
  "Palvelin on sulkenut yhteyden."
 ],
 "Session is about to expire": [
  null,
  ""
 ],
 "Set": [
  null,
  ""
 ],
 "Skip main navigation": [
  null,
  ""
 ],
 "Skip to content": [
  null,
  "Siirry sisältöön"
 ],
 "Something went wrong": [
  null,
  ""
 ],
 "Stop editing hosts": [
  null,
  ""
 ],
 "Switch to limited access": [
  null,
  ""
 ],
 "System": [
  null,
  "Järjestelmä"
 ],
 "The IP address or hostname cannot contain whitespace.": [
  null,
  "IP-osoite tai isäntänimi ei voi sisältää välilyöntiä."
 ],
 "The SSH key ${key} of ${luser} on ${lhost} will be added to the ${afile} file of ${ruser} on ${rhost}.": [
  null,
  "${luser):n SSH-avain ${key} ${lhost}:lla, lisätään ${ruser}:n tiedostoon ${afile} ${rhost}:lla."
 ],
 "The SSH key for logging in to {{#strong}}{{full_address}}{{/strong}} is protected. You can log in with either your login password or by providing the password of the key at {{#strong}}{{key}}{{/strong}}.": [
  null,
  "SSH-avain sisäänkirjautumiseen {{#strong}}{{full_address}}{{/strong}}:heenon suojattu. Voit kirjautua sisään joko kirjautumissalasanallasi tai antamalla avaimen salasanan {{#strong}}{{key}}{{/strong}}:ssa."
 ],
 "The SSH key {{#strong}}{{key}}{{/strong}} will be made available for the remainder of the session and will be available for login to other hosts as well.": [
  null,
  "SSH-avain {{#strong}}{{key}}{{/strong}} on käytettävissä koko istunnon ajan ja on käytettävissä sisäänkirjautumista varten muille isännöille myös."
 ],
 "The key password can not be empty": [
  null,
  "Avaimen salasana ei voi olla tyhjä"
 ],
 "The key passwords do not match": [
  null,
  "Avainsalasanat eivät täsmää"
 ],
 "The new key password can not be empty": [
  null,
  "Uuden avaimen salasana ei voi olla tyhjä"
 ],
 "The new key passwords do not match": [
  null,
  "Uudet avainsalasanat eivät täsmää"
 ],
 "The passwords do not match.": [
  null,
  "Salasanat eivät täsmää."
 ],
 "The resulting fingerprint is fine to share via public methods, including email.": [
  null,
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Palvelin kieltäytyi tunnistautumista käyttäen mitään tuetuista tavoista."
 ],
 "There are currently no active pages": [
  null,
  ""
 ],
 "There was an unexpected error while connecting to the machine.": [
  null,
  ""
 ],
 "This didn't work, please try again": [
  null,
  ""
 ],
 "This machine has already been added.": [
  null,
  "Tämä kone on jo lisätty."
 ],
 "This will allow you to log in without password in the future.": [
  null,
  ""
 ],
 "Tip: Make your key password match your login password to automatically authenticate against other systems.": [
  null,
  "Vinkki: Luo avaimesi salasana vastaamaan käyttäjätunnuksesi salasanaa, jotta voit automaattisesti tunnistautua muita järjestelmiä kohden."
 ],
 "To ensure that your connection is not intercepted by a malicious third-party, please verify the host key fingerprint:": [
  null,
  ""
 ],
 "To verify a fingerprint, run the following on {{host}} while physically sitting at the machine or through a trusted network:": [
  null,
  ""
 ],
 "Toggle session settings": [
  null,
  "Vaihda istunnon asetuksia"
 ],
 "Too much data": [
  null,
  "Liian paljon dataa"
 ],
 "Tools": [
  null,
  ""
 ],
 "Type": [
  null,
  "Tyyppi"
 ],
 "Unable to contact the given host $0. Make sure it has ssh running on port $1, or specify another port in the address.": [
  null,
  "Annettuun isäntään $0 ei voida ottaa yhteyttä. Varmista, että ssh on käynnissä portissa $1, tai määritä toinen portti osoitteeseen."
 ],
 "Unable to contact {{#strong}}{{host}}{{/strong}}.": [
  null,
  "{{#strong}}{{host}}{{/strong}}:een ei saa yhteyttä."
 ],
 "Unable to log in to {{#strong}}{{full_address}}{{/strong}} using SSH key authentication. Please provide the password. You may want to set up your SSH keys for automatic login.": [
  null,
  "Ei voida kirjautua {{#strong}}{{full_address}}{{/strong}}:hen käyttämällä SSH-avaimen todennusta. Anna salasana. Haluat ehkä asettaa SSH-avaimet automaattista kirjautumista varten."
 ],
 "Unable to log in to {{#strong}}{{full_address}}{{/strong}}. The host does not accept password login or any of your SSH keys.": [
  null,
  "Isäntään {{#strong}}{{full_address}}{{/strong}} kirjautuminen ei onnistu. Isäntä ei hyväksy salasanan kirjautumista tai mitään SSH-avaimiasi."
 ],
 "Unable to log in to {{#strong}}{{host}}{{/strong}}. For more authentication options and troubleshooting support please upgrade cockpit-ws to a newer version.": [
  null,
  "{{#strong}}{{host}}{{/strong}}:hen ei voi kirjautua. Lisää todennusasetuksia ja vianmääritystukea päivittämällä cockpit-ws uudempaan versioon."
 ],
 "Unable to log in to {{#strong}}{{host}}{{/strong}}. To connect to this host you will need to enable one of the following authentication methods in the sshd config on {{#strong}}{{host}}{{/strong}}:": [
  null,
  "{{#strong}}{{host}}{{/strong}}:hen ei voi kirjautua. Yhteyden muodostamiseksi tähän isäntään sinun on otettava käyttöön yksi seuraavista todennusmenetelmistä {{#strong}}{{host}}{{/strong}}:n sshd-määrityksessä:"
 ],
 "Unexpected error": [
  null,
  "Odottamaton virhe"
 ],
 "Unlock key": [
  null,
  "Avaa avaimen lukitus"
 ],
 "Untrusted host": [
  null,
  ""
 ],
 "Update": [
  null,
  "Päivitä"
 ],
 "Use the following keys to authenticate against other systems": [
  null,
  "Käytä seuraavia avaimia todentamaan muita järjestelmiä kohden"
 ],
 "User name": [
  null,
  "Käyttäjänimi"
 ],
 "Version": [
  null,
  "Versio"
 ],
 "Web Console": [
  null,
  "Verkkokonsoli"
 ],
 "When empty, connect with the current user": [
  null,
  ""
 ],
 "You are connecting to {{host}} for the first time.": [
  null,
  ""
 ],
 "You can not gain administrative access.": [
  null,
  ""
 ],
 "You have been logged out due to inactivity.": [
  null,
  ""
 ],
 "You may want to change the password of the key for automatic login.": [
  null,
  ""
 ],
 "You now have administrative access.": [
  null,
  ""
 ],
 "You will be logged out in $0 seconds.": [
  null,
  ""
 ],
 "Your browser will remember your access level across sessions.": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "Istuntosi on päätetty."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Istuntosi on vahventunut. Ole hyvä ja kirjaudu uudelleen sisään."
 ],
 "active": [
  null,
  "aktiivinen"
 ],
 "in most browsers": [
  null,
  ""
 ],
 "show less": [
  null,
  "näytä vähemmän"
 ],
 "show more": [
  null,
  "näytä enemmän"
 ],
 "{{host}} key changed": [
  null,
  "{{host}} avain vaihdettu"
 ]
});
