cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n > 1;
return plural;
},
  "language": "fr",
  "x-generator": "Weblate 4.4"
 },
 "$0 exited with code $1": [
  null,
  "$0 quitté avec le code $1"
 ],
 "$0 failed": [
  null,
  "$0 échoué"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 tué avec un signal $1"
 ],
 "Cancel": [
  null,
  "Annuler"
 ],
 "Cannot forward login credentials": [
  null,
  "Impossible de transférer les identifiants de connexion"
 ],
 "Close": [
  null,
  "Fermer"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit n’a pas pu contacter l’hôte indiqué."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit n’est pas compatible avec le logiciel sur le système."
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit n’est pas installé sur le système."
 ],
 "Connection has timed out.": [
  null,
  "La connexion a expiré."
 ],
 "Create diagnostic report                    ": [
  null,
  "Créer un rapport de diagnostic                    "
 ],
 "Create report": [
  null,
  "Créer un rapport"
 ],
 "Diagnostic Reports": [
  null,
  "Rapports de diagnostic"
 ],
 "Diagnostic reports": [
  null,
  "Rapports de diagnostic"
 ],
 "Done!": [
  null,
  "Terminé !"
 ],
 "Download report": [
  null,
  "Télécharger le rapport"
 ],
 "Generating report": [
  null,
  "Générer un rapport"
 ],
 "Host key is incorrect": [
  null,
  "La clé de l’hôte est incorrecte"
 ],
 "Internal error": [
  null,
  "Erreur interne"
 ],
 "Login failed": [
  null,
  "Échec de la connexion"
 ],
 "No archive has been created.": [
  null,
  "Aucune archive n’a été créée."
 ],
 "Not permitted to perform this action.": [
  null,
  "Non autorisé à effectuer cette action."
 ],
 "Server has closed the connection.": [
  null,
  "Le serveur a fermé la connexion."
 ],
 "The collected information will be stored locally on the system.": [
  null,
  "Les informations collectées seront stockées localement sur le système."
 ],
 "The generated archive contains data considered sensitive and its content should be reviewed by the originating organization before being passed to any third party.": [
  null,
  "L’archive générée contient des données considérées comme sensibles et son contenu doit être examiné par l’organisation d’origine avant d’être transmis à un tiers."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Le serveur a refusé d’authentifier en utilisant des méthodes prises en charge."
 ],
 "This tool will collect system configuration and diagnostic information from this system for use with diagnosing problems with the system.": [
  null,
  "Cet outil collecte les informations de configuration et de diagnostic du système à partir de ce système afin de les utiliser pour diagnostiquer les problèmes du système."
 ],
 "Too much data": [
  null,
  "Trop de données"
 ],
 "Untrusted host": [
  null,
  "Hôte non sécurisé"
 ],
 "You need to switch to \"Administrative access\" in order to create reports.": [
  null,
  "Vous devez passer à « Accès administratif » pour pouvoir créer des rapports."
 ],
 "Your session has been terminated.": [
  null,
  "Votre session a été interrompue."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Votre session a expiré. Veuillez vous reconnecter."
 ],
 "sos": [
  null,
  "sos"
 ]
});
