cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "sv",
  "x-generator": "Weblate 4.0.4"
 },
 "$0 documentation": [
  null,
  "$0 dokumentation"
 ],
 "$0 exited with code $1": [
  null,
  "$0 avslutade med kod $1"
 ],
 "$0 failed": [
  null,
  "$0 misslyckades"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 dödad med signal $1"
 ],
 "A compatible version of Cockpit is not installed on {{#strong}}{{host}}{{/strong}}.": [
  null,
  "Ingen kompatibel version av Cockpit är installerad på {{#strong}}{{host}}{{/strong}}."
 ],
 "A new SSH key at ${key} will be created for ${luser} on ${lhost} and it will be added to the ${afile} file of ${ruser} on ${rhost}.": [
  null,
  ""
 ],
 "About Web Console": [
  null,
  "Om webkonsollen"
 ],
 "Accept key and connect": [
  null,
  ""
 ],
 "Active pages": [
  null,
  "Aktiva sidor"
 ],
 "Add": [
  null,
  "Lägg till"
 ],
 "Add key": [
  null,
  "Lägg till nyckel"
 ],
 "Administrative access": [
  null,
  "Administrativ tillgång"
 ],
 "Apps": [
  null,
  ""
 ],
 "Authenticate": [
  null,
  "Autentisera"
 ],
 "Authentication": [
  null,
  "Autentisering"
 ],
 "Authentication failed": [
  null,
  "Autentisering misslyckades"
 ],
 "By changing the password of the SSH key ${key} to the login password of ${luser} on ${lhost}, the key will be automatically made available and you can log in to ${rhost} without password in the future.": [
  null,
  ""
 ],
 "Can be a hostname, IP address, alias name, or ssh:// URI": [
  null,
  ""
 ],
 "Cancel": [
  null,
  "Avbryt"
 ],
 "Cannot forward login credentials": [
  null,
  "Kan inte vidarebefordra inloggningsuppgifterna"
 ],
 "Change password": [
  null,
  "Ändra lösenord"
 ],
 "Clear search": [
  null,
  "Nollställ sökning"
 ],
 "Close": [
  null,
  "Stäng"
 ],
 "Close selected pages": [
  null,
  "Stäng valda sidor"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit kunde inte kontakta den angivna värden."
 ],
 "Cockpit had an unexpected internal error.": [
  null,
  ""
 ],
 "Cockpit is an interactive Linux server admin interface.": [
  null,
  "Cockpit är ett interaktivt administratörsgränssnitt för Linuxservrar."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit är inte kompatibelt med programvaran på systemet."
 ],
 "Cockpit is not installed": [
  null,
  "Cockpit är inte installerat"
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit är inte installerat på systemet."
 ],
 "Color": [
  null,
  "Färg"
 ],
 "Comment": [
  null,
  "Kommentar"
 ],
 "Confirm": [
  null,
  "Bekräfta"
 ],
 "Connecting simultaneously to more than {{ limit }} machines is unsupported.": [
  null,
  "Att ansluta till mer än {{ limit }} maskiner samtidigt stödjs inte."
 ],
 "Connecting to the machine": [
  null,
  "Ansluter till maskinen"
 ],
 "Connection error": [
  null,
  "Anslutningsfel"
 ],
 "Connection failed": [
  null,
  "Anslutningen misslyckades"
 ],
 "Connection has timed out.": [
  null,
  "Anslutningens tidsgräns överskreds."
 ],
 "Continue session": [
  null,
  "Fortsätt session"
 ],
 "Could not contact {{host}}": [
  null,
  "Kunde inte kontakta {{host}}"
 ],
 "Create": [
  null,
  "Skapa"
 ],
 "Create a new SSH key and authorize it.": [
  null,
  ""
 ],
 "Ctrl-Shift-J": [
  null,
  ""
 ],
 "Details": [
  null,
  "Detaljer"
 ],
 "Disconnected": [
  null,
  "Frånkopplad"
 ],
 "Display language": [
  null,
  "Visningsspråk"
 ],
 "Edit": [
  null,
  "Redigera"
 ],
 "Edit hosts": [
  null,
  ""
 ],
 "Failed to add machine: $0": [
  null,
  "Misslyckades att lägga till en maskin: $0"
 ],
 "Failed to change password": [
  null,
  "Misslyckades att ändra lösenord"
 ],
 "Failed to edit machine: $0": [
  null,
  "Misslyckades att redigera en maskin: $0"
 ],
 "Fingerprint": [
  null,
  "Fingeravtryck"
 ],
 "GNU LGPL version 2.1": [
  null,
  ""
 ],
 "Help": [
  null,
  "Hjälp"
 ],
 "Host": [
  null,
  "Värd"
 ],
 "Host key is incorrect": [
  null,
  "Värdnyckeln är felaktig"
 ],
 "If the fingerprint matches, click \"Accept key and connect\". Otherwise, do not connect and contact your administrator.": [
  null,
  ""
 ],
 "In order to allow log in to ${rhost} as ${ruser} without password in the future, use the login password of ${luser} on ${lhost} as the key password, or leave the key password blank.": [
  null,
  ""
 ],
 "Internal error": [
  null,
  "Internt fel"
 ],
 "Invalid file permissions": [
  null,
  "Felaktiga filrättigheter"
 ],
 "Is sshd running on a different port?": [
  null,
  "Kör sshd på en annan port?"
 ],
 "Kerberos based SSO": [
  null,
  "Kerberos-baserad SSO"
 ],
 "Learn more": [
  null,
  "Mer information"
 ],
 "Licensed under:": [
  null,
  "Licensierad under:"
 ],
 "Limit access": [
  null,
  "Begränsa tillgång"
 ],
 "Limited access": [
  null,
  "Begränsad tillgång"
 ],
 "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
  null,
  "Begränsat läge tar bort viss funktionalitet i webkonsollen."
 ],
 "Log in": [
  null,
  "Logga in"
 ],
 "Log in to {{host}}": [
  null,
  "Logga in på {{host}}"
 ],
 "Log out": [
  null,
  "Logga ut"
 ],
 "Login failed": [
  null,
  "Inloggningen misslyckades"
 ],
 "Messages related to the failure might be found in the journal:": [
  null,
  "Meddelanden angående detta fel kan finnas i journalen:"
 ],
 "Method": [
  null,
  "Metod"
 ],
 "New password": [
  null,
  "Nytt lösenord"
 ],
 "New password was not accepted": [
  null,
  "Det nya lösenordet godtogs inte"
 ],
 "No results found": [
  null,
  ""
 ],
 "No such file or directory": [
  null,
  "Filen eller katalogen finns inte"
 ],
 "Not a valid private key": [
  null,
  "Inte en giltig privat nyckel"
 ],
 "Not permitted to perform this action.": [
  null,
  "Inte tillåtet att utföra denna åtgärd."
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Old password": [
  null,
  "Gammalt lösenord"
 ],
 "Old password not accepted": [
  null,
  "Det gamla lösenordet accepterades inte"
 ],
 "Ooops!": [
  null,
  "Hoppsan!"
 ],
 "Password": [
  null,
  "Lösenord"
 ],
 "Password not accepted": [
  null,
  "Lösenordet accepterades inte"
 ],
 "Path to file": [
  null,
  "Sökväg till filen"
 ],
 "Please authenticate to gain administrative access": [
  null,
  ""
 ],
 "Port": [
  null,
  "Port"
 ],
 "Project website": [
  null,
  "Projektwebbsajt"
 ],
 "Prompting via ssh-add timed out": [
  null,
  "Tidsgränsen överskreds vid fråga via ssh-add"
 ],
 "Prompting via ssh-keygen timed out": [
  null,
  "Tidsgränsen överskreds vid fråga via ssh-keygen"
 ],
 "Public key": [
  null,
  "Publik nyckel"
 ],
 "Reconnect": [
  null,
  "Återanslut"
 ],
 "Safari users need to import and trust the certificate of the self-signing CA:": [
  null,
  ""
 ],
 "Search": [
  null,
  ""
 ],
 "Select": [
  null,
  "Välj"
 ],
 "Server has closed the connection.": [
  null,
  "Servern har stängt förbindelsen."
 ],
 "Session is about to expire": [
  null,
  ""
 ],
 "Set": [
  null,
  "Sätt"
 ],
 "Skip main navigation": [
  null,
  ""
 ],
 "Something went wrong": [
  null,
  ""
 ],
 "Stop editing hosts": [
  null,
  ""
 ],
 "Switch to limited access": [
  null,
  ""
 ],
 "System": [
  null,
  "System"
 ],
 "The SSH key ${key} of ${luser} on ${lhost} will be added to the ${afile} file of ${ruser} on ${rhost}.": [
  null,
  ""
 ],
 "The SSH key for logging in to {{#strong}}{{full_address}}{{/strong}} is protected. You can log in with either your login password or by providing the password of the key at {{#strong}}{{key}}{{/strong}}.": [
  null,
  ""
 ],
 "The SSH key {{#strong}}{{key}}{{/strong}} will be made available for the remainder of the session and will be available for login to other hosts as well.": [
  null,
  ""
 ],
 "The passwords do not match.": [
  null,
  "Lösenorden stämmer inte överens."
 ],
 "The resulting fingerprint is fine to share via public methods, including email.": [
  null,
  ""
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "Servern vägrade att autentisera med några stödda metoder."
 ],
 "There are currently no active pages": [
  null,
  "Det finns för närvarande inga aktiva sidor"
 ],
 "There was an unexpected error while connecting to the machine.": [
  null,
  ""
 ],
 "This didn't work, please try again": [
  null,
  ""
 ],
 "This machine has already been added.": [
  null,
  "Denna maskin har redan lagts till."
 ],
 "This will allow you to log in without password in the future.": [
  null,
  ""
 ],
 "Tip: Make your key password match your login password to automatically authenticate against other systems.": [
  null,
  "Tips: gör så att ditt nyckellösenord stämmer med ditt inloggningslösenord för att automatiskt autentisera mot andra system."
 ],
 "To ensure that your connection is not intercepted by a malicious third-party, please verify the host key fingerprint:": [
  null,
  ""
 ],
 "To verify a fingerprint, run the following on {{host}} while physically sitting at the machine or through a trusted network:": [
  null,
  ""
 ],
 "Too much data": [
  null,
  "För mycket data"
 ],
 "Tools": [
  null,
  ""
 ],
 "Type": [
  null,
  "Typ"
 ],
 "Unable to log in to {{#strong}}{{full_address}}{{/strong}} using SSH key authentication. Please provide the password. You may want to set up your SSH keys for automatic login.": [
  null,
  ""
 ],
 "Unable to log in to {{#strong}}{{full_address}}{{/strong}}. The host does not accept password login or any of your SSH keys.": [
  null,
  ""
 ],
 "Unexpected error": [
  null,
  "Oväntat fel"
 ],
 "Unlock key": [
  null,
  "Lås upp nyckeln"
 ],
 "Untrusted host": [
  null,
  "Ej betrodd värd"
 ],
 "Update": [
  null,
  "Uppdatera"
 ],
 "Use the following keys to authenticate against other systems": [
  null,
  "Använd följande nycklar för att autentisera mot andra system"
 ],
 "User name": [
  null,
  "Användarnamn"
 ],
 "Version": [
  null,
  "Version"
 ],
 "When empty, connect with the current user": [
  null,
  ""
 ],
 "You are connecting to {{host}} for the first time.": [
  null,
  ""
 ],
 "You can not gain administrative access.": [
  null,
  ""
 ],
 "You have been logged out due to inactivity.": [
  null,
  ""
 ],
 "You may want to change the password of the key for automatic login.": [
  null,
  ""
 ],
 "You now have administrative access.": [
  null,
  ""
 ],
 "You will be logged out in $0 seconds.": [
  null,
  ""
 ],
 "Your browser will remember your access level across sessions.": [
  null,
  ""
 ],
 "Your session has been terminated.": [
  null,
  "Din session har avslutats."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "Din session har gått ut.  Logga in igen."
 ],
 "active": [
  null,
  "aktiv"
 ],
 "in most browsers": [
  null,
  ""
 ],
 "show less": [
  null,
  "visa mindre"
 ],
 "show more": [
  null,
  "visa mer"
 ]
});
