.automation-script-modal pre {
    max-height: 20em;
    margin-bottom: 5px;
}

.automation-script-modal span.fa {
    margin-right: 5px;
}

.automation-script-modal i.fa {
    margin-right: 2px;
    margin-left: 5px;
}

.green-icon {
    color: var(--pf-global--success-color--100);
}
