cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=1; plural=0;
return plural;
},
  "language": "zh_CN",
  "x-generator": "Weblate 4.4.2"
 },
 "$0 exited with code $1": [
  null,
  "$0 退出，代码为 $1"
 ],
 "$0 failed": [
  null,
  "$0 失败"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 被信号 $1 终止"
 ],
 "Actions": [
  null,
  "操作"
 ],
 "Applications": [
  null,
  "应用"
 ],
 "Applications list": [
  null,
  "应用列表"
 ],
 "Cancel": [
  null,
  "取消"
 ],
 "Cannot forward login credentials": [
  null,
  "无法转发登录凭证"
 ],
 "Checking for new applications": [
  null,
  "检查新的应用"
 ],
 "Close": [
  null,
  "关闭"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit 无法联系指定的主机。"
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit 与系统上的软件不兼容。"
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit 未安装在系统上。"
 ],
 "Connection has timed out.": [
  null,
  "连接超时。"
 ],
 "Error": [
  null,
  "错误"
 ],
 "Go to application": [
  null,
  "转到应用"
 ],
 "Host key is incorrect": [
  null,
  "主机密钥不正确"
 ],
 "Install": [
  null,
  "安装"
 ],
 "Installing": [
  null,
  "正在安装"
 ],
 "Internal error": [
  null,
  "内部错误"
 ],
 "Learn more": [
  null,
  "了解更多"
 ],
 "Login failed": [
  null,
  "登录失败"
 ],
 "No applications installed or available": [
  null,
  "没有可用的安装"
 ],
 "No description provided.": [
  null,
  "没有提供说明。"
 ],
 "No installation package found for this application.": [
  null,
  "没有找到为该应用的安装包。"
 ],
 "Not permitted to perform this action.": [
  null,
  "不允许执行该操作。"
 ],
 "Ok": [
  null,
  "确认"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit 已崩溃"
 ],
 "Remove": [
  null,
  "删除"
 ],
 "Removing": [
  null,
  "正在移除"
 ],
 "Server has closed the connection.": [
  null,
  "服务器关闭了连接。"
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "服务器拒绝使用任何支持的方式来验证。"
 ],
 "Too much data": [
  null,
  "太多数据"
 ],
 "Unknown application": [
  null,
  "未知应用"
 ],
 "Untrusted host": [
  null,
  "不可信的主机"
 ],
 "Update package information": [
  null,
  "更新软件包信息"
 ],
 "View project website": [
  null,
  "查看项目网站"
 ],
 "Waiting for other programs to finish using the package manager...": [
  null,
  "正在等待其他程序来结束使用中的软件包管理器..."
 ],
 "Your session has been terminated.": [
  null,
  "会话被终止。"
 ],
 "Your session has expired. Please log in again.": [
  null,
  "会话超时。请重新登录。"
 ],
 "add-on": [
  null,
  "add-on"
 ],
 "addon": [
  null,
  "addon"
 ],
 "apps": [
  null,
  "apps"
 ],
 "extension": [
  null,
  "扩展"
 ],
 "install": [
  null,
  "安装"
 ],
 "plugin": [
  null,
  "插件"
 ]
});
